@@ -14,7 +14,7 @@ class GalleryUploadTest(TestCase):
     """Testing the admin page that allows users to upload zips."""
 
     def setUp(self):
-        super(GalleryUploadTest, self).setUp()
+        super().setUp()
         user = User.objects.create_user('john.doe',
                                         'john.doe@example.com',
                                         'secret')
@@ -28,7 +28,7 @@ class GalleryUploadTest(TestCase):
                                  'title': 'This is a test title'}
 
     def tearDown(self):
-        super(GalleryUploadTest, self).tearDown()
+        super().tearDown()
         self.zip_file.close()
         for photo in Photo.objects.all():
             photo.delete()
@@ -74,15 +74,18 @@ class GalleryUploadTest(TestCase):
 
         self.assertEqual(response['Location'], location)
 
-        self.assertQuerysetEqual(Gallery.objects.all(),
-                                 ['<Gallery: This is a test title>'])
-        self.assertQuerysetEqual(Photo.objects.all(),
-                                 ['<Photo: This is a test title 1>'])
+        self.assertQuerySetEqual(Gallery.objects.all(),
+                                 ['<Gallery: This is a test title>'],
+                                 transform=repr)
+        self.assertQuerySetEqual(Photo.objects.all(),
+                                 ['<Photo: This is a test title 1>'],
+                                 transform=repr)
 
         # The photo is attached to the gallery.
         gallery = Gallery.objects.get(title='This is a test title')
-        self.assertQuerysetEqual(gallery.photos.all(),
-                                 ['<Photo: This is a test title 1>'])
+        self.assertQuerySetEqual(gallery.photos.all(),
+                                 ['<Photo: This is a test title 1>'],
+                                 transform=repr)
 
     def test_duplicate_gallery(self):
         """If we try to create a Gallery with a title that duplicates an existing title, refuse to load."""
@@ -113,10 +116,12 @@ class GalleryUploadTest(TestCase):
             response = self.client.post('/admin/photologue/photo/upload_zip/', test_data)
             self.assertEqual(response.status_code, 302)
 
-        self.assertQuerysetEqual(Gallery.objects.all(),
-                                 ['<Gallery: This is a test title>'])
-        self.assertQuerysetEqual(Photo.objects.all(),
-                                 ['<Photo: This is a test title 1>'])
+        self.assertQuerySetEqual(Gallery.objects.all(),
+                                 ['<Gallery: This is a test title>'],
+                                 transform=repr)
+        self.assertQuerySetEqual(Photo.objects.all(),
+                                 ['<Photo: This is a test title 1>'],
+                                 transform=repr)
 
     def test_ignored(self):
         """Ignore anything that does not look like a image file.
@@ -130,10 +135,12 @@ class GalleryUploadTest(TestCase):
             response = self.client.post('/admin/photologue/photo/upload_zip/', test_data)
             self.assertEqual(response.status_code, 302)
 
-        self.assertQuerysetEqual(Gallery.objects.all(),
-                                 ['<Gallery: This is a test title>'])
-        self.assertQuerysetEqual(Photo.objects.all(),
-                                 ['<Photo: This is a test title 1>'])
+        self.assertQuerySetEqual(Gallery.objects.all(),
+                                 ['<Gallery: This is a test title>'],
+                                 transform=repr)
+        self.assertQuerySetEqual(Photo.objects.all(),
+                                 ['<Photo: This is a test title 1>'],
+                                 transform=repr)
 
     def test_existing_gallery(self):
         """Add the photos in the zip to an existing gallery."""
@@ -146,14 +153,17 @@ class GalleryUploadTest(TestCase):
         response = self.client.post('/admin/photologue/photo/upload_zip/', test_data)
         self.assertEqual(response.status_code, 302)
 
-        self.assertQuerysetEqual(Gallery.objects.all(),
-                                 ['<Gallery: Existing>'])
-        self.assertQuerysetEqual(Photo.objects.all(),
-                                 ['<Photo: Existing 1>'])
+        self.assertQuerySetEqual(Gallery.objects.all(),
+                                 ['<Gallery: Existing>'],
+                                 transform=repr)
+        self.assertQuerySetEqual(Photo.objects.all(),
+                                 ['<Photo: Existing 1>'],
+                                 transform=repr)
 
         # The photo is attached to the existing gallery.
-        self.assertQuerysetEqual(existing_gallery.photos.all(),
-                                 ['<Photo: Existing 1>'])
+        self.assertQuerySetEqual(existing_gallery.photos.all(),
+                                 ['<Photo: Existing 1>'],
+                                 transform=repr)
 
     def test_existing_gallery_custom_title(self):
         """Add the photos in the zip to an existing gallery, but specify a
@@ -167,8 +177,9 @@ class GalleryUploadTest(TestCase):
         response = self.client.post('/admin/photologue/photo/upload_zip/', test_data)
         self.assertEqual(response.status_code, 302)
 
-        self.assertQuerysetEqual(Photo.objects.all(),
-                                 ['<Photo: Custom title 1>'])
+        self.assertQuerySetEqual(Photo.objects.all(),
+                                 ['<Photo: Custom title 1>'],
+                                 transform=repr)
 
     def test_duplicate_slug(self):
         """Uploading a zip, but a photo already exists with the target slug."""
@@ -180,13 +191,14 @@ class GalleryUploadTest(TestCase):
         response = self.client.post('/admin/photologue/photo/upload_zip/', test_data)
         self.assertEqual(response.status_code, 302)
 
-        self.assertQuerysetEqual(Photo.objects.all(),
+        self.assertQuerySetEqual(Photo.objects.all(),
                                  [
                                  '<Photo: This is a test title 1>',
                                  '<Photo: This is a test title 2>',
                                  '<Photo: This is a test title 3>'
                                  ],
-                                 ordered=False)
+                                 ordered=False,
+                                 transform=repr)
 
     def test_bad_zip(self):
         """Supplied file is not a zip file - tell user."""
